# Copyright (C) 2022 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

inherit deploy

SSTATE_SKIP_CREATION = "1"

MICROSYS_IMAGE_EXTRA_INSTALL += " \
    parted e2fsprogs-resize2fs can-utils bashprofile \
    stressapptest whetstone dhrystone iperf3 memtester \
    linux-qoriq-tools \
"


IMAGE_INSTALL:append = "${MICROSYS_IMAGE_EXTRA_INSTALL}"

IMAGE_INSTALL:append = " fmc "

SDCARD_ROOTFS = "${IMGDEPLOYDIR}/${IMAGE_BASENAME}-${MACHINE}.ext4"

DEPENDS += " parted-native u-boot u-boot-qoriq-binman qoriq-atf"
RDEPENDS += " parted-native u-boot-qoriq-binman qoriq-atf"

DEPENDS += "microsys-image-ramdisk"

# Hailo support

MACHINE_ESSENTIAL_EXTRA_RRECOMMENDS += "${@bb.utils.contains('DISTRO_FEATURES', \
    'hailo', 'kernel-module-hailo-pci', '', d)}"

IMAGE_INSTALL:append = "${@bb.utils.contains('DISTRO_FEATURES', \
    'hailo', \
    ' libhailort hailortcli pyhailort libgsthailo hailo-pci hailo-firmware ', \
    '', d)}"

IMAGE_INSTALL:append = "${@bb.utils.contains('DISTRO_FEATURES', \
    'hailo', \
    ' libgsthailotools hailo-post-processes tappas-tracers ', \
    '', d)}"

do_image:ext4[depends] += "e2fsprogs-native:do_populate_sysroot"
do_image:ext3[depends] += "e2fsprogs-native:do_populate_sysroot"
do_image:sdcard[rdeptask] += "do_rootfs"
do_image:sdcard[rdeptask] += "do_image_ext4"
do_image:ext4[rdeptask] += "do_image_kernelitb"
do_image:tar[rdeptask] += "do_image_kernelitb"
do_image:tfa_sdcard[rdeptask] += "linux-qoriq:do_deploy"
do_rootfs_kernelitb[rdeptask] += "linux-qoriq:do_deploy"
do_rootfs_kernelitb[rdeptask] += "linux-qoriq:do_bundle_initramfs"

IMAGE_FSTYPES:remove = "ext2.gz"
IMAGE_FSTYPES:remove = "ext2.gz.u-boot"
IMAGE_FSTYPES += "ext4 sdcard ubi"
IMAGE_FSTYPES:qoriq += "ext4 tfa-sdcard tar.gz"

IMAGE_TYPES:remove = "ubi"

do_rootfs_u_boot() {

    install -d ${IMAGE_ROOTFS}/boot

    for ub in ${DEPLOY_DIR_IMAGE}/u-boot-${MACHINE}.bin-*; do
        if [ -f ${ub} ]; then
            file=$(realpath ${ub})
            target=$(basename ${ub})
            install -m 0644 ${file} ${IMAGE_ROOTFS}/boot/${target}
        fi
    done

    if [ ${MACHINE} = "mpxls1028crx07" ]; then
		for bl in ${DEPLOY_DIR_IMAGE}/dp/ls1028a*.bin; do
			file=$(realpath ${bl})
			install -m 0644 ${file} ${IMAGE_ROOTFS}/boot
		done
    fi

    for env in ${DEPLOY_DIR_IMAGE}/${UBOOT_ENVBIN}-*; do
        if [ -f ${env} ]; then
            cp -a ${env} ${IMAGE_ROOTFS}/boot
        fi
    done
}
addtask rootfs_u_boot after do_rootfs before do_image

do_rootfs_atf() {

    install -d ${IMAGE_ROOTFS}/boot

    for bl in ${DEPLOY_DIR_IMAGE}/atf/bl2_*.pbl; do
        file=$(realpath ${bl})
        install -m 0644 ${file} ${IMAGE_ROOTFS}/boot
    done

    for fip in ${DEPLOY_DIR_IMAGE}/atf/fip*.bin; do
        file=$(realpath ${fip})
        install -m 0644 ${file} ${IMAGE_ROOTFS}/boot
    done
}
addtask rootfs_atf after do_rootfs before do_image


do_rootfs_ubootfirmwareimage() {
    export PYTHONPATH=${RECIPE_SYSROOT}${libdir}/:$PYTHONPATH

	if [ ${MACHINE} = "mpxls1046ram2gbcrx05" ]; then
		 binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi
	if [ ${MACHINE} = "mpxls1046ram4gbcrx05" ]; then
		binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi

	if [ ${MACHINE} = "mpxls1046ram8gbcrx05" ]; then
		binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi

	if [ ${MACHINE} = "mpxls1046ram4gb2nandcrx05" ]; then
		binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi

    if [ ${MACHINE} = "mpxls1046crx06" ]; then
         	binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi

    # We are doing the same for every mpxls1043 machine
    if [ "${MACHINE}" = "mpxls1043ac1000msatacrx05" ] \
     || [ "${MACHINE}" = "mpxls1043ac1000pciecrx05" ] \
     || [ "${MACHINE}" = "mpxls1043ac1600msatacrx05" ] \
     || [ "${MACHINE}" = "mpxls1043ac1600pciecrx05" ] \
     || [ "${MACHINE}" = "mpxls1043ac1600pcie2nandcrx05" ] \
     || [ "${MACHINE}" = "mpxls1043ac1600pcie2gbnandcrx05" ] ; then
		binman build -d ${DEPLOY_DIR_IMAGE}/nand_firmware_mpxls1043.dtb -O ${DEPLOY_DIR_IMAGE}/nand_firmware_mpxls1043.img
		binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1043.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1043.img
		cp -a ${DEPLOY_DIR_IMAGE}/nand_firmware_mpxls1043.img/nand_firmware.img ${IMAGE_ROOTFS}/boot/nand_firmware.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1043.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi

    if [ ${MACHINE} = "mpxls1088crx05" ]; then
            	binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi
    if [ ${MACHINE} = "mpxls1088ram8gb2nandcrx5" ]; then
            	binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi
    if [ ${MACHINE} = "mpxls1088crx06" ]; then
         	binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi
    if [ ${MACHINE} = "mpxls1088ram8gb2nandcrx6" ]; then
         	binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi
    if [ ${MACHINE} = "mpxls1088crx06qsgmii" ]; then
         	binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi
    if [ ${MACHINE} = "mpxlx2160acrx08" ]; then
		 binman build -d ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_crx08.dtb -O ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_crx08.img
		cp -a ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_crx08.img/xspi_firmware.img ${IMAGE_ROOTFS}/boot/xspi_firmware.img
    fi
    if [ ${MACHINE} = "mpxlx2160aacu" ]; then
		 binman build -d ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_acu.dtb -O ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_acu.img
		cp -a ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_acu.img/xspi_firmware.img ${IMAGE_ROOTFS}/boot/xspi_firmware.img
    fi
    if [ ${MACHINE} = "mpxlx2160acrx08ai" ]; then
		 binman build -d ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_crx08.dtb -O ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_crx08.img
		cp -a ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_crx08.img/xspi_firmware.img ${IMAGE_ROOTFS}/boot/xspi_firmware.img
    fi

}
addtask rootfs_ubootfirmwareimage after do_rootfs before do_image

BINMAN = "/usr/bin/python3 ${DEPLOY_DIR_IMAGE}/binman"

do_rootfs_modify_dppa_udev_rules() {

    if [ ${MACHINE} = "mpxls1046crx06" ]; then
       echo "SUBSYSTEM==\"net\", DRIVERS==\"fsl_dpa*\", ATTR{device_addr}==\"1af2000\", NAME=\"fm1-mac10\"" >> ${IMAGE_ROOTFS}/${sysconfdir}/udev/rules.d/73-fsl-dpaa-persistent-networking.rules
    fi
    if [ ${MACHINE} = "mpxls1046crx06qsgmii" ]; then
       echo "SUBSYSTEM==\"net\", DRIVERS==\"fsl_dpa*\", ATTR{device_addr}==\"1af2000\", NAME=\"fm1-mac10\"" >> ${IMAGE_ROOTFS}/${sysconfdir}/udev/rules.d/73-fsl-dpaa-persistent-networking.rules
    fi
	if [ ${MACHINE} = "mpxls1088crx06" ]; then
       echo "SUBSYSTEM==\"net\", DRIVERS==\"fsl_dpa*\", ATTR{device_addr}==\"1af2000\", NAME=\"fm1-mac10\"" >> ${IMAGE_ROOTFS}/${sysconfdir}/udev/rules.d/73-fsl-dpaa-persistent-networking.rules
    fi
	if [ ${MACHINE} = "mpxls1088ram8gb2nandcrx6" ]; then
       echo "SUBSYSTEM==\"net\", DRIVERS==\"fsl_dpa*\", ATTR{device_addr}==\"1af2000\", NAME=\"fm1-mac10\"" >> ${IMAGE_ROOTFS}/${sysconfdir}/udev/rules.d/73-fsl-dpaa-persistent-networking.rules
    fi
	if [ ${MACHINE} = "mpxls1088crx06qsgmii" ]; then
       echo "SUBSYSTEM==\"net\", DRIVERS==\"fsl_dpa*\", ATTR{device_addr}==\"1af2000\", NAME=\"fm1-mac10\"" >> ${IMAGE_ROOTFS}/${sysconfdir}/udev/rules.d/73-fsl-dpaa-persistent-networking.rules
    fi
}
addtask rootfs_modify_dppa_udev_rules after do_rootfs before do_image
